Skip to contents

Check identity of the Seurat object.

Usage

check_identity_column(x, identity_column)

Arguments

x

A Seurat object.

identity_column

The name of the identity column to pull from object metadata.

Value

The name of the identity column, potentially corrected if resolution.