Skip to contents

Determine the point size for reduced dimensions scatter plots (smaller for larger datasets).

Usage

get_dr_point_size(x)

Arguments

x

Number of cells (points on the plot), a Seurat object, or a data frame with one row per cell.

Value

Numeric point size.