Function to merge two metadata tables together.
merge_metadata.Rdx and y must not share column names other than cell - stop()s if
they do, rather than letting left_join() silently rename the collision to
<col>.x/<col>.y.
merge_metadata.Rdx and y must not share column names other than cell - stop()s if
they do, rather than letting left_join() silently rename the collision to
<col>.x/<col>.y.