get_dr_point_size.Rd
Determine the point size for reduced dimensions scatter plots (smaller for larger datasets).
get_dr_point_size(x)
Number of cells (points on the plot), a Seurat object, or a data frame with one row per cell.
Numeric point size.