Read in Gene Expression and Antibody Capture data from a 10x Genomics Cell Ranger sparse matrix or from a text file.
read_counts_file.RdRead in Gene Expression and Antibody Capture data from a 10x Genomics Cell Ranger sparse matrix or from a text file.