Resolve a Seurat object, given either the object itself or a path to one on disk.
resolve_seurat_object.RdMeant for parameters that accept either an in-memory Seurat object or a serialized one - resolving here means callers do not need to check which they got themselves.